/* eslint-disable no-console */
/* eslint-disable quotes */
const express = require('express');
const CategoriaService = require('../../service/CategoriaService');
const EixoService = require('../../service/EixoService');
const SecretariaService = require('../../service/SecretariaService');
const SubprefeituraService = require('../../service/SubprefeituraService');
const ContribuicaoNaoEncontradaError = require('../../errors/ContribuicaoNaoEncontradaError');
const ContribuicaoService = require('../../service/ContribuicaoService');
const PesquisaInvalidaError = require('../../errors/PesquisaInvalidaError');

const router = express.Router();

const categoriaService = new CategoriaService();
const contribuicaoService = new ContribuicaoService();
const eixoService = new EixoService();
const secretariaService = new SecretariaService();
const subprefeituraService = new SubprefeituraService();

router.get('/', (req, res) => {
  res.json({
    message: `API - Devolutivas do Programa de Metas 2021-2024`,
  });
});

router.post('/contribuicoes/pesquisar', async (req, res) => {
  try {
    const contribuicoes = await contribuicaoService.pesquisar(req.body, req.query);
    res.send(contribuicoes);
  } catch (err) {
    if (err instanceof ContribuicaoNaoEncontradaError) {
      res.sendStatus(204);
    } else {
      console.error(err);
      res.sendStatus(500);
    }
  }
});

router.get('/contribuicao/:id', async (req, res) => {
  try {
    const contribuicao = await contribuicaoService.pesquisarPorId(req.params.id);
    res.send(contribuicao);
  } catch (err) {
    if (err instanceof ContribuicaoNaoEncontradaError) {
      res.sendStatus(204);
    } else if (err instanceof PesquisaInvalidaError) {
      res.status(400).send(err.message);
    } else {
      console.error(err);
      res.sendStatus(500);
    }
  }
});

router.get('/categorias', async (req, res) => {
  try {
    const categorias = await categoriaService.listarTodos();
    res.send(categorias);
  } catch (err) {
    console.error(err);
    res.sendStatus(500);
  }
});

router.get('/eixos', async (req, res) => {
  try {
    const eixos = await eixoService.listarTodos();
    res.send(eixos);
  } catch (err) {
    console.error(err);
    res.sendStatus(500);
  }
});

router.get('/secretarias', async (req, res) => {
  try {
    const secretarias = await secretariaService.listarTodas();
    res.send(secretarias);
  } catch (err) {
    console.error(err);
    res.sendStatus(500);
  }
});

router.get('/subprefeituras', async (req, res) => {
  try {
    const subprefeituras = await subprefeituraService.listarTodos();
    res.send(subprefeituras);
  } catch (err) {
    console.error(err);
    res.sendStatus(500);
  }
});

module.exports = router;
