require('dotenv').config();
const express = require('express');
const morgan = require('morgan');
const helmet = require('helmet');
const cors = require('cors');
const swaggerUi = require('swagger-ui-express');
const YAML = require('yamljs');
const middlewares = require('./middlewares');
const apiV1 = require('./api/v1');

const app = express();

// Habilita o log da aplicação para cada requisição
app.use(morgan(':remote-addr - [:date[clf]] ":method :url" ":response-time ms" :status'));

// Documentação Swagger
const swaggerDocument = YAML.load('./swagger.yml');
app.use('/docs', swaggerUi.serve, swaggerUi.setup(swaggerDocument));

// Middlewares de segurança - https://github.com/helmetjs/helmet
app.use(helmet());

// Configura CORS (Cross-Origin Resource Sharing) - https://github.com/expressjs/cors
app.use(cors());

// Faz o parse do JSON recebido via request body
app.use(express.json());

// Habilita o cache
app.use(middlewares.cacheMiddleware);

app.get('/', (req, res) => {
  res.json({
    message: 'API de Devolutivas do Programa de Metas'
  });
});

// Carrega as rotas da aplicação
app.use('/v1', apiV1);

// Middlewares para lidar com recursos inexistentes ou erros diversos
app.use(middlewares.notFound);
app.use(middlewares.errorHandler);

module.exports = app;
