const db = require('../db');

class ContribuicaoDAO {
  constructor() {
    this.db = db;
  }

  async pesquisar(params) {
    const where = [];
    where.push(params.idCategoria ? ' AND   categoria_id = $1' : ' AND 1 = $1');
    where.push(params.idEixo ? ' AND   eixo_id = $2' : ' AND 1 = $2');
    where.push(params.idSecretaria ? ' AND   secretaria_id = $3' : ' AND 1 = $3');
    where.push(params.idSubprefeitura ? ' AND   subprefeitura_id = $4' : ' AND 1 = $4');
    where.push(params.termoPesquisa
      ? `AND (
          municipe_nome_vector @@ to_tsquery('portuguese', unaccent($5))
          OR contribuicao_integra_vector @@ to_tsquery('portuguese', unaccent($5))
          OR subtema_nome_vector @@ to_tsquery('portuguese', unaccent($5))
          OR subtema_devolutiva_vector @@ to_tsquery('portuguese', unaccent($5))
        )`
      : ' AND 1 = $5');

    const query = {
      text: `
        SELECT  *
        FROM    vw_subtemas_pesquisa root
        WHERE   root.contribuicao_id IN (
          SELECT  DISTINCT sub.contribuicao_id
          FROM    vw_subtemas_pesquisa sub
          WHERE   1=1
          ${where.join(' ')}
          LIMIT   $6 
          OFFSET  $7
        )
        ORDER BY contribuicao_id, sugestao_id ASC
        `,
      values: [
        params.idCategoria ? params.idCategoria : 1,
        params.idEixo ? params.idEixo : 1,
        params.idSecretaria ? params.idSecretaria : 1,
        params.idSubprefeitura ? params.idSubprefeitura : 1,
        params.termoPesquisa ? params.termoPesquisa.trim().split(/\s+/).join(' & ') : 1,
        parseInt(params.limit, 10),
        parseInt(params.offset, 10),
      ]
    };
    const { rows } = await this.db.query(query);
    return rows;
  }

  async pesquisarPorId(id) {
    const query = {
      text: `
        SELECT  *
        FROM    vw_subtemas_pesquisa root
        WHERE   root.contribuicao_id = $1`,
      values: [id]
    };

    const { rows } = await this.db.query(query);
    return rows;
  }
}

module.exports = ContribuicaoDAO;
