const NodeCache = require('node-cache');
const crypto = require('crypto');

const cache = new NodeCache({ maxKeys: 10000 });

function notFound(req, res, next) {
  res.status(404);
  const error = new Error(`🔍 - Not Found - ${req.originalUrl}`);
  next(error);
}

/* eslint-disable no-unused-vars */
function errorHandler(err, req, res, next) {
  /* eslint-enable no-unused-vars */
  const statusCode = res.statusCode !== 200 ? res.statusCode : 500;
  res.status(statusCode);
  res.json({
    message: err.message,
    stack: process.env.NODE_ENV === 'production' ? '🥞' : err.stack
  });
}

function getTotalCacheSizeMB(stats) {
  const keySize = stats.ksize;
  const valueSize = stats.vsize;
  const totalSizeMB = (keySize + valueSize) / 1024 / 1024;
  return totalSizeMB.toFixed(1);
}

function printCache(req, operacao) {
  if (req.method === 'GET' || req.method === 'POST') {
    const stats = cache.getStats();
    console.log('-- Cache:', operacao, stats, 'Size:', getTotalCacheSizeMB(stats), 'MB');
  }
}

function createHash(req) {
  const hashString = req.url + JSON.stringify(req.query) + JSON.stringify(req.body);
  const hash = crypto.createHash('md5').update(hashString).digest('hex');
  return hash;
}

const cacheMiddleware = (req, res, next) => {
  const reqHash = createHash(req);
  res.header('Cache-Control', 'public, max-age=2592000000');
  if (cache.get(reqHash)) {
    printCache(req, 'FROM');
    res.json(JSON.parse(cache.get(reqHash)));
  } else {
    res.sendResponse = res.send;
    res.send = (body) => {
      if (res.statusCode === 200) {
        cache.set(reqHash, body);
        printCache(req, 'TO');
      }
      res.sendResponse(body);
    };
    next();
  }
};

module.exports = {
  notFound,
  errorHandler,
  cacheMiddleware
};
