/* eslint-disable max-len */
const Canal = require('../model/Canal');
const Categoria = require('../model/Categoria');
const Contribuicao = require('../model/Contribuicao');
const ContribuicaoDAO = require('../dao/ContribuicaoDAO');
const ContribuicaoNaoEncontradaError = require('../errors/ContribuicaoNaoEncontradaError');
const Eixo = require('../model/Eixo');
const PesquisaInvalidaError = require('../errors/PesquisaInvalidaError');
const Secretaria = require('../model/Secretaria');
const Subprefeitura = require('../model/Subprefeitura');
const Sugestao = require('../model/Sugestao');
const Tema = require('../model/Tema');

class ContribuicaoService {
  constructor() {
    this.dao = new ContribuicaoDAO();
  }

  async pesquisar(params = {}, query = {}) {
    // Define o limite de registros a serem retornados (padrão = 10, máximo = 100)
    params.limit = ContribuicaoService.processarLimite(query.limit);

    // Define a posição a partir da qual serão retornados os registros (padrão: 0)
    params.offset = query.offset ? query.offset : 0;

    // Realiza a pesquisa no banco
    const rows = await this.dao.pesquisar(params);

    // Converte os registros retornados pelo banco de dados num array de contribuições
    if (rows.length < 1) throw new ContribuicaoNaoEncontradaError();

    let contribuicoes = [];
    contribuicoes = ContribuicaoService.converterContribuicoes(rows);

    return contribuicoes;
  }

  static converterContribuicoes(rows) {
    const contribuicoes = [];
    let contribuicaoAtual = {};
    rows.forEach((row) => {
      const subprefeitura = new Subprefeitura(row.subprefeitura_id, row.subprefeitura_nome);
      const categoria = new Categoria(row.categoria_id, row.categoria_nome);
      const eixo = new Eixo(row.eixo_id, row.eixo_nome);
      const secretaria = new Secretaria(row.secretaria_id, row.secretaria_sigla);
      const tema = new Tema(row.subtema_id, row.subtema_nome, categoria, eixo, secretaria, row.subtema_devolutiva);
      const sugestao = new Sugestao(row.sugestao_id, row.sugestao_conteudo, subprefeitura, tema);

      // Mesma contribuição com sugestão nova
      if (row.contribuicao_id === contribuicaoAtual.id) {
        contribuicaoAtual.sugestoes.push(sugestao);
      } else {
        // Nova contribuição
        if (Object.keys(contribuicaoAtual).length > 0) contribuicoes.push(contribuicaoAtual);
        const canal = new Canal(row.canal_id, row.canal_nome, row.canal_introducao);
        const sugestoes = [sugestao];
        contribuicaoAtual = new Contribuicao(row.contribuicao_id, row.municipe_nome, canal, row.contribuicao_integra, sugestoes);
      }
    });
    contribuicoes.push(contribuicaoAtual);

    return contribuicoes;
  }

  static processarLimite(limit) {
    if (!limit) return 10;
    if (limit > 100) return 100;
    return limit;
  }

  async pesquisarPorId(id) {
    const somenteNumeros = id.match(/^[0-9]*$/);
    if (!somenteNumeros) throw new PesquisaInvalidaError('Erro: O ID informado é invalido!');
    const rows = await this.dao.pesquisarPorId(id);
    if (rows.length < 1) throw new ContribuicaoNaoEncontradaError();
    const contribuicoes = ContribuicaoService.converterContribuicoes(rows);
    return contribuicoes[0];
  }
}

module.exports = ContribuicaoService;
