/* eslint-disable import/no-extraneous-dependencies */
const request = require('supertest');

const app = require('../src/app');

describe('GET /v1/pesquisar', () => {
  it('deve retornar erro 404', (done) => {
    request(app)
      .get('/v1/pesquisar')
      .set('Accept', 'application/json')
      .expect('Content-Type', /json/)
      .expect(404, done);
  });
});

describe('POST /v1/contribuicoes/pesquisar', () => {
  it('deve retornar um array de contribuições (sem parâmetros)', (done) => {
    request(app)
      .post('/v1/contribuicoes/pesquisar')
      .set('Accept', 'application/json')
      .expect('Content-Type', /json/)
      .expect(200)
      .expect((res) => {
        if (typeof res.body !== typeof []) throw new Error(`Deveria retornar um array mas retornou [${typeof res.body}]`);
        if (res.body.length < 1) throw new Error('Retornou um array vazio!');
        const receivedProperties = Object.keys(res.body[0]);
        const expectedProperties = ['id', 'canal', 'integra', 'sugestoes'];
        expectedProperties.forEach((prop) => {
          if (!receivedProperties.includes(prop)) throw new Error(`Objeto retornado não possui o campo [${prop}]!`);
        });
        if (typeof res.body[0].sugestoes !== typeof []) throw new Error(`Deveria retornar um array de sugestões mas retornou [${typeof res.body}]`);
      })
      .end(done);
  });

  it('deve respeitar o limite informado', (done) => {
    request(app)
      .post('/v1/contribuicoes/pesquisar?limit=2')
      .set('Accept', 'application/json')
      .expect('Content-Type', /json/)
      .expect(200)
      .expect((res) => {
        if (res.body.length !== 2) throw new Error('O total de registros não bate com o limite informado!');
      })
      .end(done);
  });
});
