CREATE TABLE "tb_canal" (
  "id" SERIAL PRIMARY KEY,
  "nome" varchar(255) UNIQUE NOT NULL,
  "introducao" TEXT NOT NULL
);

CREATE TABLE "tb_categoria" (
  "id" SERIAL PRIMARY KEY,
  "nome" varchar(255) UNIQUE NOT NULL
);

CREATE TABLE "tb_eixo" (
  "id" SERIAL PRIMARY KEY,
  "nome" varchar(255) UNIQUE NOT NULL
);

CREATE TABLE "tb_municipe" (
  "id" SERIAL PRIMARY KEY,
  "id_origem" varchar(255) NOT NULL,
  "nome" varchar(255) NOT NULL,
  "nome_vector" tsvector
);

CREATE TABLE "tb_secretaria" (
  "id" SERIAL PRIMARY KEY,
  "sigla" varchar(10)
);

CREATE TABLE "tb_subprefeitura" (
  "id" SERIAL PRIMARY KEY,
  "nome" varchar(255) NOT NULL
);

CREATE TABLE "tb_contribuicao" (
  "id" SERIAL PRIMARY KEY,
  "id_origem" varchar(255) NOT NULL,
  "id_canal" int,
  "id_municipe" int,
  "conteudo" text NOT NULL,
  "conteudo_vector" tsvector
);

CREATE TABLE "tb_sugestao" (
  "id" SERIAL PRIMARY KEY,
  "id_origem" varchar(255) NOT NULL,
  "id_contribuicao" int,
  "id_subprefeitura" int,
  "id_subtema" int,
  "conteudo" text NOT NULL
);

CREATE TABLE "tb_subtema" (
  "id" SERIAL PRIMARY KEY,
  "id_origem" varchar(255) NOT NULL,
  "id_categoria" int,
  "id_eixo" int,
  "id_secretaria" int,
  "nome" varchar(255) NOT NULL,
  "nome_vector" tsvector,
  "devolutiva" text NOT NULL,
  "devolutiva_vector" tsvector
);

ALTER TABLE "tb_contribuicao" ADD FOREIGN KEY ("id_canal") REFERENCES "tb_canal" ("id");

ALTER TABLE "tb_contribuicao" ADD FOREIGN KEY ("id_municipe") REFERENCES "tb_municipe" ("id");

ALTER TABLE "tb_sugestao" ADD FOREIGN KEY ("id_contribuicao") REFERENCES "tb_contribuicao" ("id");

ALTER TABLE "tb_sugestao" ADD FOREIGN KEY ("id_subprefeitura") REFERENCES "tb_subprefeitura" ("id");

ALTER TABLE "tb_sugestao" ADD FOREIGN KEY ("id_subtema") REFERENCES "tb_subtema" ("id");

ALTER TABLE "tb_subtema" ADD FOREIGN KEY ("id_categoria") REFERENCES "tb_categoria" ("id");

ALTER TABLE "tb_subtema" ADD FOREIGN KEY ("id_eixo") REFERENCES "tb_eixo" ("id");

ALTER TABLE "tb_subtema" ADD FOREIGN KEY ("id_secretaria") REFERENCES "tb_secretaria" ("id");

COMMENT ON TABLE "tb_canal" IS 'Armazena os canais de recebimento das contribuições. Ex: Participe+, Audiência pública etc.';

COMMENT ON TABLE "tb_categoria" IS 'Armazena as categorias dos subtemas. Ex: Saúde, Educação etc.';

COMMENT ON TABLE "tb_eixo" IS 'Armazena os eixos do Programa de Metas. Ex: SP Mais Ágil, SP Global e Sustentável etc.';

COMMENT ON TABLE "tb_municipe" IS 'Armazena a lista de munícipes que enviaram contribuições.';

COMMENT ON TABLE "tb_secretaria" IS 'Armazena as secretarias da Prefeitura. Ex: SMS, SME, SMT.';

COMMENT ON TABLE "tb_subprefeitura" IS 'Armazena as subprefeituras da Prefeitura. Ex: Subprefeitura do Ipiranga.';

COMMENT ON TABLE "tb_contribuicao" IS 'Armazena as contribuições recebidas pelos munícipes.';

COMMENT ON TABLE "tb_sugestao" IS 'Armazena as sugestões geradas a partir das contribuições recebidas.';

COMMENT ON TABLE "tb_subtema" IS 'Armazena as devolutivas/subtemas gerados a partir das sugestões.';
