# Instruções de deploy da aplicação

## Ambiente AWS

O provisionamento do ambiente da aplicação na nuvem AWS pode ser feito através do CloudFormation, utilizando como base o arquivo `cloudformation.yml`.

O CloudFormation está previamente configurado para provisionar automaticamente:
- os security groups para acesso via SSH e Web (80/443);
- o endereço de IP elástico;
- um storage EBS de 8GB SSD gp3;
- uma instância do tipo `t3a.small` (2 vCPUs / 2 GB RAM) com Docker instalado.

## Deploy em Produção

1. Acessar o servidor remoto e clonar este repositório.

```sh
sudo su
git clone http://codigoaberto.prefeitura.sp.gov.br/sgm/devolutivas-pdm.git
cd devolutivas-pdm
```

2. Criar e configurar os arquivos `.env` do frontend e backend (em suas respectivas pastas) com base nos arquivos `.env.sample`.

```sh
cp frontend/.env.sample frontend/.env
cp backend/.env.sample backend/.env
```

3. Realizar o build das imagens docker do frontend e backend conforme abaixo:

```sh
cd frontend
docker build -t devolutivas-frontend .
cd ../backend
docker build -t devolutivas-backend .
```

4. Criar a rede `traefik-net` no docker e realizar o deploy da stack Docker Swarm conforme abaixo:

```sh
# voltar para a raíz do projeto
cd ..
docker network create -d overlay --scope=swarm traefik-net
docker stack deploy -c docker-swarm.yml devolutivas-pdm
```

## Atualização de versão

1. Remover a stack do Docker swarm:

```sh
docker stack rm devolutivas-pdm
```

2. Remover as imagens Docker do frontend/backend:

```sh
docker rmi $(docker images 'devolutivas-frontend' -a -q)
docker rmi $(docker images 'devolutivas-backend' -a -q)
```

3. Repetir os passos 3 e 4 do deploy em produção (realizar novo build das imagens e deploy da stack).
